.. Korta documentation master file, created by
   sphinx-quickstart on Fri Dec  9 14:26:38 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Korta Client Skjölun
====================

Innihald:

.. toctree::
   :maxdepth: 2

   uppsetning
   byrjunarskref
   kodi

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

